<?php
/**
 * Icon Arena Pro Theme Customizer
 *
 * @package Icon Arena Pro
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function icon_arena_pro_customize_register( $wp_customize ) {
    $wp_customize->remove_control( 'header_image' );
	$wp_customize->get_setting( 'blogname' )->transport         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->transport  = 'postMessage';
	$wp_customize->add_section( 'icon_arena_pro_logo_section' , array(
    'title'       => esc_attr( 'Logo', 'icon-arena-pro' ),
    'priority'    => 30,
    'description' => esc_attr('Upload a logo to replace the default site name and description in the more', 'icon-arena-pro' ),
    ) );
    
    $wp_customize->add_setting( 'icon_arena_pro_logo',
        'sanitize_callback' == 'esc_url_raw'
    );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'icon_arena_pro_logo', array(
        'label'    => esc_attr( 'Logo', 'icon-arena-pro' ),
        'section'  => 'icon_arena_pro_logo_section',
        'settings' => 'icon_arena_pro_logo',
        'sanitize_callback' => 'esc_url_raw',
    ) ) );

    // google fonts
    require_once( dirname( __FILE__ ) . '/google-fonts/fonts.php' );


    $wp_customize->add_section( 'icon_arena_pro_google_fonts', array(
        'title'    => esc_html__( 'Fonts', 'icon-arena-pro' ),
        'priority' => 50,
    ) );

    $wp_customize->add_setting( 'icon_arena_pro_google_fonts_heading_font', array(
        'default'           => 'none',
        'type'              => 'theme_mod',
        'capability'        => 'edit_theme_options',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( 'icon_arena_pro_google_fonts_heading_font', array(
        'label'    => esc_html__( 'Header Font', 'icon-arena-pro' ),
        'section'  => 'icon_arena_pro_google_fonts',
        'settings' => 'icon_arena_pro_google_fonts_heading_font',
        'type'     => 'select',
        'choices'  => $font_choices,
    ) );

    $wp_customize->add_setting( 'icon_arena_pro_google_fonts_body_font', array(
        'default'           => 'Roboto',
        'type'              => 'theme_mod',
        'capability'        => 'edit_theme_options',
        'transport'         => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    $wp_customize->add_control( 'icon_arena_pro_google_fonts_body_font', array(
        'label'    => esc_html__( 'Body Font', 'icon-arena-pro' ),
        'section'  => 'icon_arena_pro_google_fonts',
        'settings' => 'icon_arena_pro_google_fonts_body_font',
        'type'     => 'select',
        'choices'  => $font_choices,
    ) );
    // end google fonts

    $wp_customize->add_section( 'post', array(
            'title' => esc_html__( 'Home Layout', 'icon-arena-pro' ),
            'description'=> '',
            'priority' => 92,
    ) );

    $wp_customize->add_setting( 
        'post_layout', 
        array(
            'default' => 'two',
            'sanitize_callback' => 'sanitize_key'
        )
    );

    $wp_customize->add_control( 
        'post_layout', 
        array(
            'label' => esc_html__( 'Post Settings', 'icon-arena-pro' ),
            'section' => 'post',
            'type' => 'radio',

            'choices' => array(
                'one' => esc_html__('1 Column Post','icon-arena-pro'),
                'two' => esc_html__('2 Column Posts','icon-arena-pro'),
                'three' => esc_html__('3 Column Posts','icon-arena-pro')               
            )
        )
    );

    $wp_customize->add_section( 'layout', array(
            'title' => esc_html__( 'Layout Style', 'icon-arena-pro' ),
            'description'=> '',
            'priority' => 93,
    ) );

    $wp_customize->add_setting( 
        'site_layout', 
        array(
            'default' => 'full', 
            'sanitize_callback' => 'sanitize_key'
        )
    );

    $wp_customize->add_control( 
        'site_layout', 
        array(
            'label' => esc_html__( 'Layout Style', 'icon-arena-pro' ),
            'section' => 'layout',
            'type' => 'radio',

            'choices' => array(
                'full' => esc_html__('Full Width','icon-arena-pro'),
                'boxed' => esc_html__('Boxed','icon-arena-pro'),          
            )
        )
    );

    $wp_customize->add_section( 'icon_arena_pro_new_section_site_colors' , array(
        'title'      => esc_html__('Site Colors', 'icon-arena-pro'),
        'description'=> '',
        'priority'   => 95,
    ) );

    $wp_customize->add_setting(
        'icon_arena_pro_header_bg',
        array(
            
            'sanitize_callback' => 'sanitize_hex_color'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_main_color',
        array(
            
            'sanitize_callback' => 'sanitize_hex_color'
        )
    );

    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'icon_arena_pro_header_bg',
            array(
                'label'      => esc_html__('Header BG', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_site_colors',
                'settings'   => 'icon_arena_pro_header_bg',
                'priority'   => 1
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Color_Control(
            $wp_customize,
            'icon_arena_pro_main_color',
            array(
                'label'      => esc_html__('Main Color', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_site_colors',
                'settings'   => 'icon_arena_pro_main_color',
                'priority'   => 2
            )
        )
    );


    $wp_customize->add_section( 'icon_arena_pro_new_section_social' , array(
        'title'      => esc_html__('Social Media Settings', 'icon-arena-pro'),
        'description'=> '',
        'priority'   => 94,
    ) );

    // Social Media
        
    $wp_customize->add_setting(
        'icon_arena_pro_facebook',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_twitter',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_instagram',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_pinterest',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_tumblr',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_bloglovin',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_tumblr',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_google',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_youtube',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );
    $wp_customize->add_setting(
        'icon_arena_pro_rss',
        array(
            'default'     => '',
            'sanitize_callback' => 'sanitize_text_field'
        )
    );


    // Social Media
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'facebook',
            array(
                'label'      => esc_html__('Facebook', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_facebook',
                'type'       => 'text',
                'priority'   => 1
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'twitter',
            array(
                'label'      => esc_html__('Twitter', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_twitter',
                'type'       => 'text',
                'priority'   => 2
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'instagram',
            array(
                'label'      => esc_html__('Instagram', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_instagram',
                'type'       => 'text',
                'priority'   => 3
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'pinterest',
            array(
                'label'      => esc_html__('Pinterest', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_pinterest',
                'type'       => 'text',
                'priority'   => 4
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'bloglovin',
            array(
                'label'      => esc_html__('Bloglovin', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_bloglovin',
                'type'       => 'text',
                'priority'   => 5
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'google',
            array(
                'label'      => esc_html__('Google Plus', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_google',
                'type'       => 'text',
                'priority'   => 6
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'tumblr',
            array(
                'label'      => esc_html__('Tumblr', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_tumblr',
                'type'       => 'text',
                'priority'   => 7
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'youtube',
            array(
                'label'      => esc_html__('Youtube', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_youtube',
                'type'       => 'text',
                'priority'   => 8
            )
        )
    );
    $wp_customize->add_control(
        new WP_Customize_Control(
            $wp_customize,
            'rss',
            array(
                'label'      => esc_html__('RSS Link', 'icon-arena-pro'),
                'section'    => 'icon_arena_pro_new_section_social',
                'settings'   => 'icon_arena_pro_rss',
                'type'       => 'text',
                'priority'   => 8
            )
        )
    );


}
add_action( 'customize_register', 'icon_arena_pro_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously.
 */
function icon_arena_pro_customize_preview_js() {
	wp_enqueue_script( 'icon_arena_pro_customizer', get_template_directory_uri() . '/js/customizer.js', array( 'customize-preview' ), '20130508', true );
}
add_action( 'customize_preview_init', 'icon_arena_pro_customize_preview_js' );


function icon_arena_pro_sanitize_choices( $input, $setting ) {
    global $wp_customize;
 
    $control = $wp_customize->get_control( $setting->id );
 
    if ( array_key_exists( $input, $control->choices ) ) {
        return $input;
    } else {
        return $setting->default;
    }
}

// Customizer - Add CSS

function icon_arena_pro_customizer_css() {
        
    ?>
    <style type="text/css">

        .site-branding { background:<?php echo esc_attr(get_theme_mod( 'icon_arena_pro_header_bg' )); ?>; }

        .site-header { background:<?php echo esc_attr(get_theme_mod( 'icon_arena_pro_main_bg' )); ?>; }
        .entry-title a, .entry-title a:visited, .entry-title-single { color:<?php echo esc_attr(get_theme_mod( 'icon_arena_pro_main_color' )); ?>; }
        
        <?php if( get_theme_mod('site_layout', 'full') == 'full') : ?>
        .site-header, .site-footer{
            max-width: 100%;   
        }

        <?php elseif( get_theme_mod('site_layout') == 'boxed') : ?>
        .site-header, .site-footer{
            max-width: 1010px;  
            margin: 0 auto; 
        }

        <?php endif; ?>


        <?php if( get_theme_mod('post_layout') == 'one') : ?>
        .grid{
                display: grid;
                grid-template-columns: 100%;
            }
        img.default, img.default-no-img{
                float: left;
               
            }
        .entry-thumbnail img, img.default-no-img{
            width: auto;
            height: 148px;
            float: left;
            padding-right: 10px;
        }

        <?php elseif( get_theme_mod('post_layout', 'two') == 'two') : ?>
        .grid{
            display: grid;
            grid-template-columns: 50% 50%;
            grid-gap: 20px;
            padding: 5px;
        }
        .entry-thumbnail img, img.default-no-img{
            width: 100%;
            height: 220px;
            float: left;
            padding-right: 10px;
        }

        @media only screen and (max-width:500px) {
        .grid{
            display: grid;
            grid-template-columns: 100%;
            
        }
        
        <?php elseif( get_theme_mod('post_layout') == 'three') : ?>
        .grid{
            display: grid;
            grid-template-columns: 33% 33% 33%;
            grid-gap: 10px;
            padding: 5px;
        }
       
        @media only screen and (max-width:860px) {
        .grid{
            display: grid;
            grid-template-columns: 50% 50%;
            grid-gap: 20px;
            padding: 5px;
        }
        
        @media only screen and (max-width:500px) {
        .grid{
            display: grid;
            grid-template-columns: 100%;
            
        }
        }
        <?php endif; ?>

        

    </style>
    <?php
}
add_action( 'wp_head', 'icon_arena_pro_customizer_css' );
?>